@@ -27,13 +27,15 @@ or logging context.
 """
 
 import collections
+import functools
 import itertools
 import threading
 import uuid
 import warnings
 
 import debtcollector
-from positional import positional
+from debtcollector import renames
+
 
 _request_store = threading.local()
 
@@ -42,13 +44,13 @@ _request_store = threading.local()
 _ENVIRON_HEADERS = {
     'auth_token': ['HTTP_X_AUTH_TOKEN',
                    'HTTP_X_STORAGE_TOKEN'],
-    'user': ['HTTP_X_USER_ID',
-             'HTTP_X_USER'],
-    'tenant': ['HTTP_X_PROJECT_ID',
-               'HTTP_X_TENANT_ID',
-               'HTTP_X_TENANT'],
-    'user_domain': ['HTTP_X_USER_DOMAIN_ID'],
-    'project_domain': ['HTTP_X_PROJECT_DOMAIN_ID'],
+    'user_id': ['HTTP_X_USER_ID',
+                'HTTP_X_USER'],
+    'project_id': ['HTTP_X_PROJECT_ID',
+                   'HTTP_X_TENANT_ID',
+                   'HTTP_X_TENANT'],
+    'user_domain_id': ['HTTP_X_USER_DOMAIN_ID'],
+    'project_domain_id': ['HTTP_X_PROJECT_DOMAIN_ID'],
     'user_name': ['HTTP_X_USER_NAME'],
     'project_name': ['HTTP_X_PROJECT_NAME',
                      'HTTP_X_TENANT_NAME'],
@@ -131,22 +133,16 @@ class _DeprecatedPolicyValues(collections.MutableMapping):
         return d
 
 
-# FIXME(dims): Skip deprecation warnings until Pike (Version 2.14)
-_log_deprecation_warnings = False
-
-
 def _moved_msg(new_name, old_name):
     if old_name:
         deprecated_msg = "Property '%(old_name)s' has moved to '%(new_name)s'"
         deprecated_msg = deprecated_msg % {'old_name': old_name,
                                            'new_name': new_name}
 
-        # FIXME(dims): Skip deprecation warnings until Pike (Version 2.14)
-        if _log_deprecation_warnings:
-            debtcollector.deprecate(deprecated_msg,
-                                    version='2.6',
-                                    removal_version='3.0',
-                                    stacklevel=5)
+        debtcollector.deprecate(deprecated_msg,
+                                version='2.6',
+                                removal_version='3.0',
+                                stacklevel=5)
 
 
 def _moved_property(new_name, old_name=None, target=None):
@@ -169,6 +165,12 @@ def _moved_property(new_name, old_name=None, target=None):
     return property(getter, setter, deleter)
 
 
+_renamed_kwarg = functools.partial(renames.renamed_kwarg,
+                                   version='2.18',
+                                   removal_version='3.0',
+                                   replace=True)
+
+
 class RequestContext(object):
 
     """Helper class to represent useful information about a request context.
@@ -178,15 +180,22 @@ class RequestContext(object):
     """
 
     user_idt_format = u'{user} {tenant} {domain} {user_domain} {p_domain}'
+    # Can be overridden in subclasses to specify extra keys that should be
+    # read when constructing a context using from_dict.
+    FROM_DICT_EXTRA_KEYS = []
 
-    @positional(enforcement=positional.WARN)
+    @_renamed_kwarg('user', 'user_id')
+    @_renamed_kwarg('tenant', 'project_id')
+    @_renamed_kwarg('domain', 'domain_id')
+    @_renamed_kwarg('user_domain', 'user_domain_id')
+    @_renamed_kwarg('project_domain', 'project_domain_id')
     def __init__(self,
                  auth_token=None,
-                 user=None,
-                 tenant=None,
-                 domain=None,
-                 user_domain=None,
-                 project_domain=None,
+                 user_id=None,
+                 project_id=None,
+                 domain_id=None,
+                 user_domain_id=None,
+                 project_domain_id=None,
                  is_admin=False,
                  read_only=False,
                  show_deleted=False,
@@ -221,11 +230,11 @@ class RequestContext(object):
         :type is_admin_project: bool
         """
         # setting to private variables to avoid triggering subclass properties
-        self._user_id = user
-        self._project_id = tenant
-        self._domain_id = domain
-        self._user_domain_id = user_domain
-        self._project_domain_id = project_domain
+        self._user_id = user_id
+        self._project_id = project_id
+        self._domain_id = domain_id
+        self._user_domain_id = user_domain_id
+        self._project_domain_id = project_domain_id
 
         self.auth_token = auth_token
         self.user_name = user_name
@@ -321,6 +330,7 @@ class RequestContext(object):
 
         return {'user': self.user_id,
                 'tenant': self.project_id,
+                'project': self.project_id,
                 'domain': self.domain_id,
                 'user_domain': self.user_domain_id,
                 'project_domain': self.project_domain_id,
@@ -343,6 +353,13 @@ class RequestContext(object):
                   'user_domain_name': self.user_domain_name,
                   'project_domain_name': self.project_domain_name}
         values.update(self.to_dict())
+        if self.auth_token:
+            # NOTE(jaosorior): Gotta obfuscate the token since this dict is
+            # meant for logging and we shouldn't leak it.
+            values['auth_token'] = '***'
+        else:
+            values['auth_token'] = None
+
         return values
 
     @property
@@ -356,14 +373,19 @@ class RequestContext(object):
         return self.global_request_id or self.request_id
 
     @classmethod
+    @_renamed_kwarg('user', 'user_id')
+    @_renamed_kwarg('tenant', 'project_id')
+    @_renamed_kwarg('domain', 'domain_id')
+    @_renamed_kwarg('user_domain', 'user_domain_id')
+    @_renamed_kwarg('project_domain', 'project_domain_id')
     def from_dict(cls, values, **kwargs):
         """Construct a context object from a provided dictionary."""
         kwargs.setdefault('auth_token', values.get('auth_token'))
-        kwargs.setdefault('user', values.get('user'))
-        kwargs.setdefault('tenant', values.get('tenant'))
-        kwargs.setdefault('domain', values.get('domain'))
-        kwargs.setdefault('user_domain', values.get('user_domain'))
-        kwargs.setdefault('project_domain', values.get('project_domain'))
+        kwargs.setdefault('user_id', values.get('user'))
+        kwargs.setdefault('project_id', values.get('tenant'))
+        kwargs.setdefault('domain_id', values.get('domain'))
+        kwargs.setdefault('user_domain_id', values.get('user_domain'))
+        kwargs.setdefault('project_domain_id', values.get('project_domain'))
         kwargs.setdefault('is_admin', values.get('is_admin', False))
         kwargs.setdefault('read_only', values.get('read_only', False))
         kwargs.setdefault('show_deleted', values.get('show_deleted', False))
@@ -379,9 +401,16 @@ class RequestContext(object):
                           values.get('project_domain_name'))
         kwargs.setdefault('is_admin_project',
                           values.get('is_admin_project', True))
+        for key in cls.FROM_DICT_EXTRA_KEYS:
+            kwargs.setdefault(key, values.get(key))
         return cls(**kwargs)
 
     @classmethod
+    @_renamed_kwarg('user', 'user_id')
+    @_renamed_kwarg('tenant', 'project_id')
+    @_renamed_kwarg('domain', 'domain_id')
+    @_renamed_kwarg('user_domain', 'user_domain_id')
+    @_renamed_kwarg('project_domain', 'project_domain_id')
     def from_environ(cls, environ, **kwargs):
         """Load a context object from a request environment.
 
@@ -428,7 +457,7 @@ class RequestContext(object):
 def get_admin_context(show_deleted=False):
     """Create an administrator context."""
     context = RequestContext(None,
-                             tenant=None,
+                             project_id=None,
                              is_admin=True,
                              show_deleted=show_deleted,
                              overwrite=False)
