@@ -54,6 +54,24 @@ class Object(object):
     pass
 
 
+class TestContext(context.RequestContext):
+    """A test context with additional members
+
+    This is representative of how at least some of our consumers use the
+    RequestContext class in their projects.
+    """
+    FROM_DICT_EXTRA_KEYS = ['foo']
+
+    def __init__(self, foo=None, **kwargs):
+        super(TestContext, self).__init__(**kwargs)
+        self.foo = foo
+
+    def to_dict(self):
+        d = super(TestContext, self).to_dict()
+        d['foo'] = self.foo
+        return d
+
+
 class ContextTest(test_base.BaseTestCase):
 
     def setUp(self):
@@ -182,6 +200,13 @@ class ContextTest(test_base.BaseTestCase):
         self.assertFalse(ctx.is_admin)
         self.assertTrue(ctx.read_only)
 
+    def test_from_dict_extended(self):
+        initial = TestContext(foo='bar')
+        dct = initial.to_dict()
+        final = TestContext.from_dict(dct)
+        self.assertEqual('bar', final.foo)
+        self.assertEqual(dct, final.to_dict())
+
     def test_is_user_context(self):
         self.assertFalse(context.is_user_context(None))
         ctx = context.RequestContext(is_admin=True)
@@ -461,6 +486,7 @@ class ContextTest(test_base.BaseTestCase):
 
         d = ctx.get_logging_values()
         self.assertIn('auth_token', d)
+        self.assertEqual(d['auth_token'], '***')
         self.assertIn('user', d)
         self.assertIn('tenant', d)
         self.assertIn('domain', d)
@@ -562,13 +588,6 @@ class ContextTest(test_base.BaseTestCase):
                           'service_roles': service_roles},
                          ctx.to_policy_values())
 
-    def test_positional_args(self):
-        context.RequestContext('abc', 'def')
-
-        self.assertEqual(1, len(self.warnings.log))
-        self.assertIn('__init__ takes at most 1 positional',
-                      str(self.warnings.log[0].message))
-
     def test_policy_deprecations(self):
         user = uuid.uuid4().hex
         user_domain = uuid.uuid4().hex
@@ -599,38 +618,33 @@ class ContextTest(test_base.BaseTestCase):
             self.assertIn(key, str(w[0].message))
 
     def test_deprecated_args(self):
-        user = uuid.uuid4().hex
-        tenant = uuid.uuid4().hex
-        domain = uuid.uuid4().hex
-        user_domain = uuid.uuid4().hex
-        project_domain = uuid.uuid4().hex
+        user_id = uuid.uuid4().hex
+        project_id = uuid.uuid4().hex
+        domain_id = uuid.uuid4().hex
+        user_domain_id = uuid.uuid4().hex
+        project_domain_id = uuid.uuid4().hex
 
-        ctx = context.RequestContext(user=user,
-                                     tenant=tenant,
-                                     domain=domain,
-                                     user_domain=user_domain,
-                                     project_domain=project_domain)
+        ctx = context.RequestContext(user_id=user_id,
+                                     project_id=project_id,
+                                     domain_id=domain_id,
+                                     user_domain_id=user_domain_id,
+                                     project_domain_id=project_domain_id)
 
         self.assertEqual(0, len(self.warnings))
-        self.assertEqual(user, ctx.user_id)
-        self.assertEqual(tenant, ctx.project_id)
-        self.assertEqual(domain, ctx.domain_id)
-        self.assertEqual(user_domain, ctx.user_domain_id)
-        self.assertEqual(project_domain, ctx.project_domain_id)
+        self.assertEqual(user_id, ctx.user_id)
+        self.assertEqual(project_id, ctx.project_id)
+        self.assertEqual(domain_id, ctx.domain_id)
+        self.assertEqual(user_domain_id, ctx.user_domain_id)
+        self.assertEqual(project_domain_id, ctx.project_domain_id)
 
         self.assertEqual(0, len(self.warnings))
-        self.assertEqual(user, ctx.user)
-        if context._log_deprecation_warnings:
-            self.assertEqual(1, len(self.warnings))
-        self.assertEqual(tenant, ctx.tenant)
-        if context._log_deprecation_warnings:
-            self.assertEqual(2, len(self.warnings))
-        self.assertEqual(domain, ctx.domain)
-        if context._log_deprecation_warnings:
-            self.assertEqual(3, len(self.warnings))
-        self.assertEqual(user_domain, ctx.user_domain)
-        if context._log_deprecation_warnings:
-            self.assertEqual(4, len(self.warnings))
-        self.assertEqual(project_domain, ctx.project_domain)
-        if context._log_deprecation_warnings:
-            self.assertEqual(5, len(self.warnings))
+        self.assertEqual(user_id, ctx.user)
+        self.assertEqual(1, len(self.warnings))
+        self.assertEqual(project_id, ctx.tenant)
+        self.assertEqual(2, len(self.warnings))
+        self.assertEqual(domain_id, ctx.domain)
+        self.assertEqual(3, len(self.warnings))
+        self.assertEqual(user_domain_id, ctx.user_domain)
+        self.assertEqual(4, len(self.warnings))
+        self.assertEqual(project_domain_id, ctx.project_domain)
+        self.assertEqual(5, len(self.warnings))
